import { Component, OnInit } from "@angular/core";
import * as app from 'tns-core-modules/application/application';
import { Item } from "./item";
import { ItemService } from "./item.service";

import { Mediafilepicker, ImagePickerOptions, VideoPickerOptions, AudioPickerOptions, FilePickerOptions } from 'nativescript-mediafilepicker';


@Component({
    selector: "ns-items",
    moduleId: module.id,
    templateUrl: "./items.component.html",
})
export class ItemsComponent implements OnInit {
    items: Item[];

    // This pattern makes use of Angular’s dependency injection implementation to inject an instance of the ItemService service into this class.
    // Angular knows about this service because it is included in your app’s main NgModule, defined in app.module.ts.
    constructor(private itemService: ItemService) { }

    ngOnInit(): void {
        this.items = this.itemService.getItems();
    }

    openImages() {

        let options: ImagePickerOptions = {
            android: {
                maxNumberFiles: 25,
                isNeedCamera: true,
                isNeedFolderList: true
            },
            ios: {
                isCaptureMood: false,
                maxNumberFiles: 25
            }
        };

        let mediafilepicker = new Mediafilepicker();
        mediafilepicker.on("getFiles", (res: any) => {
            console.dir(res);
            //	this.processFiles(res);
        })

        mediafilepicker.on("error", (res) => {
            let msg = res.object.get('msg');
            console.log(msg);
        });

        mediafilepicker.on("cancel", (res) => {
            let msg = res.object.get('msg');
            console.log(msg);
        });

        mediafilepicker.openImagePicker(options);
    }

    openVideos() {

        let allowedVideoQualities = [];

        if (app.ios) {
            allowedVideoQualities = [AVCaptureSessionPreset1920x1080, AVCaptureSessionPresetHigh];  //get more from here: https://developer.apple.com/documentation/avfoundation/avcapturesessionpreset?language=objc
        }

        let options: VideoPickerOptions = {
            android: {
                isNeedCamera: true,
                maxNumberFiles: 2,
                isNeedFolderList: true,
                maxDuration: 20,

            },
            ios: {
                isCaptureMood: false,
                videoMaximumDuration: 10,
                allowedVideoQualities: allowedVideoQualities
            }
        };

        let mediafilepicker = new Mediafilepicker();
        mediafilepicker.openVideoPicker(options);

        mediafilepicker.on("getFiles", function (res) {
            let results = res.object.get('results');
            console.dir(results);
        })

        mediafilepicker.on("error", function (res) {
            let msg = res.object.get('msg');
            console.log(msg);
        });

        mediafilepicker.on("cancel", function (res) {
            let msg = res.object.get('msg');
            console.log(msg);
        });
    }
}